tkmilan.validation
==================

.. automodule:: tkmilan.validation

   
   
   .. rubric:: Module Attributes

   .. autosummary::
   
      LIMIT_ISTRING
      LIMIT_INFINITE
      limT
      smvT
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      StaticMapLabels
      StaticMapValues
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      LimitBounded
      LimitUnbounded
      StaticList
      StaticMap
      VSpec
   
   

   
   
   



